@@ -38,10 +38,9 @@ undo_symbol_bytes = b"\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x14\x00\x0
 redo_symbol_bytes = b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x14\x00\x00\x00\x14\x08\x06\x00\x00\x00\x8d\x89\x1d\r\x00\x00\x00cIDATx\x9c\xed\xd2\xb1\x0e\x80@\x08\x03\xd0b\xfc\xff_>\'\xd4\x0b\x8dr\xd0\xc1\xc1\x8e\xa4y0\x00\xd43\xd8pk\x80\x14\xed\x82\x01U\x80\x13j\x95+\x1ebo`\x16\xbaD\x15\xe4\x1e\x03\x19\x96\xe9\x19\x00\xec\x99R"g\xef\x0e\x0eVX\xc1\x80\xfe\xdb\x84\xc5>\xa8^\x17\xa2z\xec\t\x94]\xe7\xa04?\xf8A\xf0\x00\xc1\x1f\r$\x92}T\x8b\x00\x00\x00\x00IEND\xaeB`\x82'
 # fmt: off
 
-WIDTH = 1080
-HEIGHT = 720
 SIZE = 25
 
+# Config for sttk app
 DEFAULT_CONFIG = {
     "application": "py_simple_image_editor",
     "icon": sttk.get_asset("ico.png"),
@@ -70,12 +69,25 @@ def bind_popup(binding, widget, menu):
 
 
 class Editor(ttk.Frame):
-    def __init__(self, parent):
+    def __init__(self, parent:tk.Frame | ttk.Frame, file:str=None, size:bool|tuple =None):
         ttk.Frame.__init__(self, parent)
 
-        self.file = None
+        self.file = file
+
+        if self.file:
+            img = Image.open(file)
+            try:
+                img.seek(1)
+            except EOFError:
+                animated = False
+            else:
+                animated = True
+            size = size if not size is None else img.size
+        size = size if not size is None else (SIZE, SIZE)
+
+        self.width, self.height = size
         self.tool_controller = tool_controller
-        self.project = PixelProject(SIZE, SIZE)
+        self.project = PixelProject(*size)
         self.drawtips_references = []
 
         # fmt: off
@@ -104,7 +116,7 @@ class Editor(ttk.Frame):
 
         (left_column_panes := tk.PanedWindow(left_side_frame, orient = "vertical", sashpad=3, sashrelief ="sunken", borderwidth = 0)).pack(fill = "both", expand = True, padx = 4, pady = (0,4))
 
-        (gif_view := LayerViewer(self.project, SIZE, SIZE, left_column_panes)).pack(fill = "both", expand = True)
+        (gif_view := LayerViewer(self.project, self.project.width, self.project.height, left_column_panes)).pack(fill = "both", expand = True)
         left_column_panes.add(gif_view)
         
         self.frame_manager = LayerManager(self, left_column_panes)
@@ -266,8 +278,16 @@ class Editor(ttk.Frame):
         self.scheduled_canvas_resize = None
         self.bind("<Configure>", self.on_canvas_resize)
 
+        if self.file:
+            for f in self.project.frames.copy():
+                del f
+            self.project.frames = []
+            if animated:
+                self.project.import_gif(self.file)
+            else:
+                self.project.import_image(self.file)
         self.after_idle(self.refresh)
-
+                
     def undo(self, event = None):
         self.project.selected_frame.selected_layer.undo()
         self.refresh()
@@ -717,11 +737,11 @@ class LoadedImageEditor(Editor):
         Editor.__init__(self, *arg, **kwargs)
 
 class App(sttk.App):
-    def __init__(self):
+    def __init__(self, file:str=None):
         if not os.path.isfile("config.json"):
             temp = sttk.make_temp_config_file(DEFAULT_CONFIG)
         sttk.App.__init__(self, temp)
-        Editor(self.window).pack(fill="both", expand=True)
+        Editor(self.window, file).pack(fill="both", expand=True)
         self.window.after_idle(lambda:sttk.tcl_center_window(self.window))
 
     def use_theme(self, theme: str = None, verbose: bool = False) -> str:
@@ -739,9 +759,9 @@ class App(sttk.App):
 
         return theme
 
-def main():
+def main(file:str=None):
     print("Running py_simple_image_editor...")
-    App().mainloop()
+    App(file).mainloop()
     sys.exit("Exited.")
 
 
